==> haskell-th-orphans-0.13.11-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-orphans
version:              0.13.11
visibility:           public
id:                   th-orphans-0.13.11-LY1XVNWpQfJAmpxToj2OUG
key:                  th-orphans-0.13.11-LY1XVNWpQfJAmpxToj2OUG
license:              BSD-3-Clause
copyright:            (c) Matt Morrow, Michael Sloan, Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Matt Morrow, Michael Sloan, Ryan Scott
stability:            experimental
synopsis:             Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.

category:             Template Haskell
abi:                  cd630bab07a8ab2948ccdb192b5057a5
exposed:              True
exposed-modules:      Language.Haskell.TH.Instances
hidden-modules:       Language.Haskell.TH.Instances.Internal
import-dirs:          /usr/lib/ghc-8.10.3/site-local/th-orphans-0.13.11
library-dirs:         /usr/lib/ghc-8.10.3/site-local/th-orphans-0.13.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/th-orphans-0.13.11
hs-libraries:         HSth-orphans-0.13.11-LY1XVNWpQfJAmpxToj2OUG
depends:
    base-4.14.1.0 mtl-2.2.2 template-haskell-2.16.0.0
    th-compat-0.1-E8qmoOaVtZoHTxxAZ6dSkY
    th-lift-0.8.2-7d37mrJ37yC1VcDgqjDphG
    th-lift-instances-0.1.18-J1wrgRQydnF2hDDcQTn1Q9
    th-reify-many-0.1.9-Cqi8wPLI2Ct5JnKBZFAGwB

haddock-interfaces:   /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html:         /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-orphans-0.13.11-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-orphans
version:              0.13.11
visibility:           public
id:                   th-orphans-0.13.11-DVTSDNTbeqb3LAxAB7WMRK
key:                  th-orphans-0.13.11-DVTSDNTbeqb3LAxAB7WMRK
license:              BSD-3-Clause
copyright:            (c) Matt Morrow, Michael Sloan, Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Matt Morrow, Michael Sloan, Ryan Scott
stability:            experimental
synopsis:             Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.

category:             Template Haskell
abi:                  4c10e02cbc2a89b0439f1797438c366f
exposed:              True
exposed-modules:      Language.Haskell.TH.Instances
hidden-modules:       Language.Haskell.TH.Instances.Internal
import-dirs:          /usr/lib/ghc-8.10.3/site-local/th-orphans-0.13.11
library-dirs:         /usr/lib/ghc-8.10.3/site-local/th-orphans-0.13.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/th-orphans-0.13.11
hs-libraries:         HSth-orphans-0.13.11-DVTSDNTbeqb3LAxAB7WMRK
depends:
    base-4.14.1.0 mtl-2.2.2 template-haskell-2.16.0.0
    th-compat-0.1-LNEn3nXaFgXC5zMkPdJGQA
    th-lift-0.8.2-7d37mrJ37yC1VcDgqjDphG
    th-lift-instances-0.1.18-L0dce56Pl6tKuhfv4xPTkD
    th-reify-many-0.1.9-Cqi8wPLI2Ct5JnKBZFAGwB

haddock-interfaces:   /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html:         /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
